pub enum XFrameOptions {
Deny,
SameOrigin,
}Expand description
Value for the X-Frame-Options header.
Controls whether the page can be embedded in an <iframe>.
Variants
Deny
No page may embed this response in a frame.
SameOrigin
Only pages from the same origin may embed this response.